"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Path = require("path");
var os = require("os");
var util_1 = require("./util");
/**
 * @param machine Reserved for future use, in case behavior differs based on OS or other environment attributes.
 * @returns absolute path to a global shared cache directory into which we can download and extract powershell versions.
 */
function getCacheInstallDirectory(machine) {
    if (machine === void 0) { machine = process; }
    if (util_1.isGlobalInstall) {
        return Path.join(util_1.getNpmGlobalNodeModules(), '@cspotcode/get-powershell-cache');
        // TODO should cache in NPM_PREFIX for --global installations
    }
    else {
        return Path.join(os.homedir(), '.npm-get-powershell');
    }
}
exports.getCacheInstallDirectory = getCacheInstallDirectory;
function getCacheManifestPath() {
    return Path.join(getCacheInstallDirectory(), 'cache-manifest.json');
}
exports.getCacheManifestPath = getCacheManifestPath;
function readCacheManifest() {
    var manifest = util_1.readJsonFileWithDefault(getCacheManifestPath(), {});
    return manifest;
}
exports.readCacheManifest = readCacheManifest;
function writeCacheManifest(manifest) {
    util_1.writeJsonFile(getCacheManifestPath(), manifest, true);
}
exports.writeCacheManifest = writeCacheManifest;
