#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var Path = require("path");
var mkdirp_1 = require("mkdirp");
var fs = require("fs");
var assert = require("assert");
var util_1 = require("./util");
var which = require("which");
var version_utils_1 = require("./version-utils");
var cache_1 = require("./cache");
var log = console.log.bind(console);
var isGlobalInstall = !!process.env.npm_config_global;
function main() {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var ownBinPath, foundPath, _i, _a, cacheInstallationDirectory, symlinkTarget, _b, version, build, cacheDirnameForBuild, manifest, archiveDownloadPath, extractionTargetPath, _c, sha256, _d;
        return tslib_1.__generator(this, function (_e) {
            switch (_e.label) {
                case 0:
                    ownBinPath = util_1.getNpmBinShimPath('pwsh');
                    // Type assertion required until https://github.com/DefinitelyTyped/DefinitelyTyped/pull/22437 is merged
                    for (_i = 0, _a = which.sync('pwsh', { nothrow: true, all: true }) || []; _i < _a.length; _i++) {
                        foundPath = _a[_i];
                        // Skip the powershell command that this package puts on the path; that's not the one we want
                        if (util_1.pathsEquivalent(foundPath, ownBinPath))
                            continue; // TODO if foundPath is a *symlink* to ownBinPath
                        // TODO verify that it's the desired version of pwsh
                        // TODO this is being totally ignored right now!!
                    }
                    // did not find it
                    foundPath = null;
                    if (foundPath) {
                        log('Found pwsh on PATH; no action required.');
                        util_1.createSymlinkTo(ownBinPath, foundPath, log);
                        process.exit(0);
                    }
                    cacheInstallationDirectory = cache_1.getCacheInstallDirectory();
                    mkdirp_1.sync(cacheInstallationDirectory, { mode: 448 });
                    _b = version_utils_1.getBestBuild(), version = _b.version, build = _b.build;
                    cacheDirnameForBuild = version_utils_1.getDirnameForBuild({ version: version, build: build });
                    manifest = cache_1.readCacheManifest();
                    if (manifest[cacheDirnameForBuild]) {
                        symlinkTarget = Path.resolve(cacheInstallationDirectory, cacheDirnameForBuild, manifest[cacheDirnameForBuild].relativePathToBin);
                        try {
                            // Assert that path both exists and is executable
                            assert(fs.statSync(symlinkTarget).mode & 64);
                        }
                        catch (e) {
                            symlinkTarget = undefined;
                        }
                    }
                    archiveDownloadPath = Path.join(cacheInstallationDirectory, version_utils_1.getFilenameForBuild({ version: version, build: build }));
                    extractionTargetPath = Path.join(cacheInstallationDirectory, cacheDirnameForBuild);
                    if (!!symlinkTarget) return [3 /*break*/, 9];
                    _c = fs.existsSync(archiveDownloadPath);
                    if (!_c) return [3 /*break*/, 2];
                    return [4 /*yield*/, util_1.sha256OfFile(archiveDownloadPath)];
                case 1:
                    _c = (_e.sent()) === build.sha256;
                    _e.label = 2;
                case 2:
                    if (!_c) return [3 /*break*/, 3];
                    log("Found archive on disk; skipping download. (" + archiveDownloadPath + ")");
                    return [3 /*break*/, 7];
                case 3:
                    // Download the archive
                    log("Downloading Powershell archive from " + build.url + " to " + archiveDownloadPath + "...");
                    return [4 /*yield*/, util_1.downloadUrlToFile(build.url, archiveDownloadPath)];
                case 4:
                    _e.sent();
                    log('Download finished.');
                    return [4 /*yield*/, util_1.sha256OfFile(archiveDownloadPath)];
                case 5:
                    sha256 = _e.sent();
                    _d = assert;
                    return [4 /*yield*/, sha256];
                case 6:
                    _d.apply(void 0, [(_e.sent()) === build.sha256, "SHA256 verification failed; download appears corrupt.  Expected " + build.sha256 + ", got " + sha256]);
                    _e.label = 7;
                case 7:
                    // Extract the archive.
                    log("Extracting archive to " + extractionTargetPath + "...");
                    mkdirp_1.sync(extractionTargetPath);
                    return [4 /*yield*/, util_1.extractArchive(build.extension, archiveDownloadPath, extractionTargetPath)];
                case 8:
                    _e.sent();
                    log("Extracted to " + extractionTargetPath);
                    symlinkTarget = Path.resolve(extractionTargetPath, build.bin);
                    // Store the desired symlink target into our cache manifest
                    util_1.patchJsonFile(cache_1.getCacheManifestPath(), {
                        indent: true, defaultValue: {}
                    }, function (json) {
                        json[cacheDirnameForBuild] = { relativePathToBin: build.bin };
                    });
                    _e.label = 9;
                case 9: 
                // Replace our stub with a symlink to the real powershell installation
                return [4 /*yield*/, util_1.createSymlinkTo(ownBinPath, symlinkTarget, log)];
                case 10:
                    // Replace our stub with a symlink to the real powershell installation
                    _e.sent();
                    log("Done!");
                    return [2 /*return*/];
            }
        });
    });
}
main().catch(function (err) {
    console.error(err);
    process.exit(1);
});
