"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var versions_1 = require("./versions");
var util_1 = require("./util");
/**
 * Returns the version and build of powershell we should install, or undefined if no know candidate is found.
 */
function getBestBuild(machine) {
    if (machine === void 0) { machine = process; }
    for (var _i = 0, versions_2 = versions_1.versions; _i < versions_2.length; _i++) {
        var v = versions_2[_i];
        for (var _a = 0, _b = v.builds; _a < _b.length; _a++) {
            var b = _b[_a];
            if (b.arch === machine.arch && b.platform === machine.platform) {
                return { version: v, build: b };
            }
        }
    }
}
exports.getBestBuild = getBestBuild;
/**
 * Directory name for a specific PowerShell build's installation.
 */
function getDirnameForBuild(_a) {
    var version = _a.version, build = _a.build;
    return "powershell-" + version.version + "-" + build.platform + "-" + build.arch;
}
exports.getDirnameForBuild = getDirnameForBuild;
/**
 * Filename for a specific PowerShell build's download file, used to save tarball / zipfile into local cache.
 */
function getFilenameForBuild(vb) {
    return "" + getDirnameForBuild(vb) + vb.build.extension;
}
exports.getFilenameForBuild = getFilenameForBuild;
/** Invoke the ambient pwsh and get its $PSVersionTable */
function getPSVersionTable() {
    var stdout = util_1.getStdout(['pwsh', '-noprofile', '-command', '$PSVersionTable | convertto-json']);
    return JSON.parse(stdout);
}
exports.getPSVersionTable = getPSVersionTable;
