
    async function extractAppImage() {
        mkdirpSync(extractionTargetPath, {mode: 0o700});
        // Set the execute bit
        fs.chmodSync(gzipDownloadPath, fs.statSync(gzipDownloadPath).mode | 0o100);

        /*
         * Unfortunately, at the time of writing, the PowerShell AppImage is using an older version of AppImage and can't fully extract itself.
         * However, the only thing it fails to extract is a directory, so we can do that ourselves.
         * 
         * We must manually extract each file, one at a time, and when we detect the specific failure noted above, we create the directory manually.
         */
        const filesToExtract = filesInAppImage;
        filesToExtract.forEach((fileToExtract, i) => {
            log(`Extracting ${ fileToExtract } (${ Math.round(i / filesToExtract.length * 100) }%)...`);
            const spawnResult = spawnSync(gzipDownloadPath, ['--appimage-extract', fileToExtract], {
                cwd: extractionTargetPath,
                encoding: 'utf8'
            });
            const {stdout, stderr} = spawnResult;
            if(spawnResult.status) {
                throw new Error('AppImage failed to extract:\n' + stderr);
            }
            // catch the expected inode_type 8 failures
            const expected = 'TODO: Implement inode.base.inode_type 8';
            if(spawnResult.stderr.indexOf(expected) > -1) {
                const dir = Path.join(extractionTargetPath, 'squashfs-root', fileToExtract);
                log(`Manually creating directory: ${ dir }`);
                mkdirpSync(dir, {mode: 0o700});
            }
        });
    }