interface Version {
    /** Should match the filename of the AppImage to avoid confusion. */
    nameAndVersion: string;
    /** URL to download Powershell's AppImage */
    appImageUrl: string;
    /** Sha256 hash of powershell's appimage.  MUST BE LOWERCASE because that's what node's buffers spit out when converted to hex */
    appImageSha256: string;
    /** Must this AppImage be extracted one file at a time or can we do it all at once? */
    mustBeExtractedOneFileAtATime: boolean;
    /**
     * All files in PowerShell's AppImage archive
     * Used when we must manually extract each file one at a time.
     * 
     * This list can be generated by downloading the AppImage tool and running:
     *     AppImage-tool -l ./path/to/powershell.appimage
     */
    filesInAppImage?: Array<string>;
}
const v6_0_0_beta7_x86_64: Version = {
    nameAndVersion: 'PowerShell-6.0.0-beta.7-x86_64',
    appImageUrl: 'https://github.com/PowerShell/PowerShell/releases/download/v6.0.0-beta.7/PowerShell-6.0.0-beta.7-x86_64.AppImage',
    appImageSha256: '0d0c030170f791eb2a8a7c4958cdf34f0584bd2d354925239321331e5e8bc1ac',
    mustBeExtractedOneFileAtATime: true,
    filesInAppImage: `
        .DirIcon
        AppRun
        ThirdPartyNotices.txt
        bin
        bin/run-parts
        bin/tar
        bin/tempfile
        bin/which
        powershell.desktop
        powershell.png
        sbin
        sbin/installkernel
        sbin/mkhomedir_helper
        sbin/pam_tally
        sbin/pam_tally2
        sbin/shadowconfig
        sbin/start-stop-daemon
        sbin/unix_chkpwd
        sbin/unix_update
        usr
        usr/bin
        usr/bin/DELETE_ME_TO_DISABLE_CONSOLEHOST_TELEMETRY
        usr/bin/Microsoft.ApplicationInsights.dll
        usr/bin/Microsoft.CSharp.dll
        usr/bin/Microsoft.CodeAnalysis.CSharp.dll
        usr/bin/Microsoft.CodeAnalysis.dll
        usr/bin/Microsoft.Management.Infrastructure.Native.dll
        usr/bin/Microsoft.Management.Infrastructure.dll
        usr/bin/Microsoft.PowerShell.Commands.Management.dll
        usr/bin/Microsoft.PowerShell.Commands.Management.xml
        usr/bin/Microsoft.PowerShell.Commands.Utility.dll
        usr/bin/Microsoft.PowerShell.Commands.Utility.xml
        usr/bin/Microsoft.PowerShell.ConsoleHost.dll
        usr/bin/Microsoft.PowerShell.ConsoleHost.xml
        usr/bin/Microsoft.PowerShell.CoreCLR.AssemblyLoadContext.dll
        usr/bin/Microsoft.PowerShell.CoreCLR.AssemblyLoadContext.xml
        usr/bin/Microsoft.PowerShell.CoreCLR.Eventing.dll
        usr/bin/Microsoft.PowerShell.CoreCLR.Eventing.xml
        usr/bin/Microsoft.PowerShell.PSReadLine.dll
        usr/bin/Microsoft.PowerShell.PSReadLine.xml
        usr/bin/Microsoft.PowerShell.SDK.dll
        usr/bin/Microsoft.PowerShell.SDK.pdb
        usr/bin/Microsoft.PowerShell.SDK.xml
        usr/bin/Microsoft.PowerShell.Security.dll
        usr/bin/Microsoft.PowerShell.Security.xml
        usr/bin/Microsoft.VisualBasic.dll
        usr/bin/Microsoft.Win32.Primitives.dll
        usr/bin/Microsoft.Win32.Registry.AccessControl.dll
        usr/bin/Microsoft.Win32.Registry.dll
        usr/bin/Modules
        usr/bin/Modules/Microsoft.PowerShell.Archive
        usr/bin/Modules/Microsoft.PowerShell.Archive/1.1.0.0
        usr/bin/Modules/Microsoft.PowerShell.Archive/1.1.0.0/Microsoft.PowerShell.Archive.cat
        usr/bin/Modules/Microsoft.PowerShell.Archive/1.1.0.0/Microsoft.PowerShell.Archive.psd1
        usr/bin/Modules/Microsoft.PowerShell.Archive/1.1.0.0/Microsoft.PowerShell.Archive.psm1
        usr/bin/Modules/Microsoft.PowerShell.Archive/1.1.0.0/en-US
        usr/bin/Modules/Microsoft.PowerShell.Archive/1.1.0.0/en-US/ArchiveResources.psd1
        usr/bin/Modules/Microsoft.PowerShell.Archive/en-US
        usr/bin/Modules/Microsoft.PowerShell.Archive/en-US/Microsoft.PowerShell.Archive.psm1-help.xml
        usr/bin/Modules/Microsoft.PowerShell.Host
        usr/bin/Modules/Microsoft.PowerShell.Host/Microsoft.PowerShell.Host.psd1
        usr/bin/Modules/Microsoft.PowerShell.Management
        usr/bin/Modules/Microsoft.PowerShell.Management/Microsoft.PowerShell.Management.psd1
        usr/bin/Modules/Microsoft.PowerShell.Security
        usr/bin/Modules/Microsoft.PowerShell.Security/Microsoft.PowerShell.Security.psd1
        usr/bin/Modules/Microsoft.PowerShell.Utility
        usr/bin/Modules/Microsoft.PowerShell.Utility/Microsoft.PowerShell.Utility.psd1
        usr/bin/Modules/Microsoft.PowerShell.Utility/Microsoft.PowerShell.Utility.psm1
        usr/bin/Modules/PSDesiredStateConfiguration
        usr/bin/Modules/PSDesiredStateConfiguration/PSDesiredStateConfiguration.psm1
        usr/bin/Modules/PSReadLine
        usr/bin/Modules/PSReadLine/PSReadLine.psd1
        usr/bin/Modules/PSReadLine/PSReadLine.psm1
        usr/bin/Modules/PackageManagement
        usr/bin/Modules/PackageManagement/1.1.4.0
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagement
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagement/MSFT_PackageManagement.psm1
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagement/MSFT_PackageManagement.schema.mfl
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagement/MSFT_PackageManagement.schema.mof
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagement/MSFT_PackageManagement.strings.psd1
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagementSource
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagementSource/MSFT_PackageManagementSource.psm1
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagementSource/MSFT_PackageManagementSource.schema.mfl
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagementSource/MSFT_PackageManagementSource.schema.mof
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/MSFT_PackageManagementSource/MSFT_PackageManagementSource.strings.psd1
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/PackageManagementDscUtilities.psm1
        usr/bin/Modules/PackageManagement/1.1.4.0/DSCResources/PackageManagementDscUtilities.strings.psd1
        usr/bin/Modules/PackageManagement/1.1.4.0/PackageManagement.cat
        usr/bin/Modules/PackageManagement/1.1.4.0/PackageManagement.format.ps1xml
        usr/bin/Modules/PackageManagement/1.1.4.0/PackageManagement.psd1
        usr/bin/Modules/PackageManagement/1.1.4.0/PackageManagement.psm1
        usr/bin/Modules/PackageManagement/1.1.4.0/PackageProviderFunctions.psm1
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.ArchiverProviders.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.ArchiverProviders.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.CoreProviders.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.CoreProviders.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.MetaProvider.PowerShell.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.MetaProvider.PowerShell.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.NuGetProvider.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.NuGetProvider.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PackageManagement.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PowerShell.PackageManagement.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/coreclr/Microsoft.PowerShell.PackageManagement.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.ArchiverProviders.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.ArchiverProviders.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.CoreProviders.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.CoreProviders.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.MetaProvider.PowerShell.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.MetaProvider.PowerShell.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.MsiProvider.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.MsiProvider.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.MsuProvider.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.MsuProvider.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.NuGetProvider.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.NuGetProvider.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PackageManagement.pdb
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PowerShell.PackageManagement.dll
        usr/bin/Modules/PackageManagement/1.1.4.0/fullclr/Microsoft.PowerShell.PackageManagement.pdb
        usr/bin/Modules/Pester
        usr/bin/Modules/Pester/Build.bat
        usr/bin/Modules/Pester/CHANGELOG.md
        usr/bin/Modules/Pester/Examples
        usr/bin/Modules/Pester/Examples/Calculator
        usr/bin/Modules/Pester/Examples/Calculator/Add-Numbers.Tests.ps1
        usr/bin/Modules/Pester/Examples/Calculator/Add-Numbers.ps1
        usr/bin/Modules/Pester/Examples/Validator
        usr/bin/Modules/Pester/Examples/Validator/Validator.Tests.ps1
        usr/bin/Modules/Pester/Functions
        usr/bin/Modules/Pester/Functions/Assertions
        usr/bin/Modules/Pester/Functions/Assertions/Be.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Be.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeGreaterThan.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeGreaterThan.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeLessThan.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeLessThan.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeNullOrEmpty.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeNullOrEmpty.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeOfType.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/BeOfType.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Contain.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Contain.ps1
        usr/bin/Modules/Pester/Functions/Assertions/ContainExactly.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/ContainExactly.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Exist.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Exist.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Match.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Match.ps1
        usr/bin/Modules/Pester/Functions/Assertions/MatchExactly.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/MatchExactly.ps1
        usr/bin/Modules/Pester/Functions/Assertions/PesterThrow.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/PesterThrow.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Should.Tests.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Should.ps1
        usr/bin/Modules/Pester/Functions/Assertions/Test-Assertion.ps1
        usr/bin/Modules/Pester/Functions/BreakAndContinue.Tests.ps1
        usr/bin/Modules/Pester/Functions/Context.Tests.ps1
        usr/bin/Modules/Pester/Functions/Context.ps1
        usr/bin/Modules/Pester/Functions/Coverage.Tests.ps1
        usr/bin/Modules/Pester/Functions/Coverage.ps1
        usr/bin/Modules/Pester/Functions/Describe.Tests.ps1
        usr/bin/Modules/Pester/Functions/Describe.ps1
        usr/bin/Modules/Pester/Functions/GlobalMock-A.Tests.ps1
        usr/bin/Modules/Pester/Functions/GlobalMock-B.Tests.ps1
        usr/bin/Modules/Pester/Functions/In.Tests.ps1
        usr/bin/Modules/Pester/Functions/In.ps1
        usr/bin/Modules/Pester/Functions/InModuleScope.Tests.ps1
        usr/bin/Modules/Pester/Functions/InModuleScope.ps1
        usr/bin/Modules/Pester/Functions/It.Tests.ps1
        usr/bin/Modules/Pester/Functions/It.ps1
        usr/bin/Modules/Pester/Functions/Mock.Tests.ps1
        usr/bin/Modules/Pester/Functions/Mock.ps1
        usr/bin/Modules/Pester/Functions/New-Fixture.Tests.ps1
        usr/bin/Modules/Pester/Functions/New-Fixture.ps1
        usr/bin/Modules/Pester/Functions/PesterState.Tests.ps1
        usr/bin/Modules/Pester/Functions/PesterState.ps1
        usr/bin/Modules/Pester/Functions/SetupTeardown.Tests.ps1
        usr/bin/Modules/Pester/Functions/SetupTeardown.ps1
        usr/bin/Modules/Pester/Functions/TestDrive.Tests.ps1
        usr/bin/Modules/Pester/Functions/TestDrive.ps1
        usr/bin/Modules/Pester/Functions/TestResults.Tests.ps1
        usr/bin/Modules/Pester/Functions/TestResults.ps1
        usr/bin/Modules/Pester/Functions/TestsRunningInCleanRunspace.Tests.ps1
        usr/bin/Modules/Pester/LICENSE
        usr/bin/Modules/Pester/Pester.Tests.ps1
        usr/bin/Modules/Pester/Pester.nuspec
        usr/bin/Modules/Pester/Pester.psd1
        usr/bin/Modules/Pester/Pester.psm1
        usr/bin/Modules/Pester/README.md
        usr/bin/Modules/Pester/Snippets
        usr/bin/Modules/Pester/Snippets/Context.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/Describe.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/It.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldBe.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldBeGreaterThan.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldBeLessThan.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldBeNullOrEmpty.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldContain.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldExist.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldMatch.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldNotBe.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldNotBeNullOrEmpty.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldNotContain.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldNotExist.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldNotMatch.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldNotThrow.snippets.ps1xml
        usr/bin/Modules/Pester/Snippets/ShouldThrow.snippets.ps1xml
        usr/bin/Modules/Pester/bin
        usr/bin/Modules/Pester/bin/pester.bat
        usr/bin/Modules/Pester/build.psake.ps1
        usr/bin/Modules/Pester/chocolateyInstall.ps1
        usr/bin/Modules/Pester/download.sh
        usr/bin/Modules/Pester/en-US
        usr/bin/Modules/Pester/en-US/about_BeforeEach_AfterEach.help.txt
        usr/bin/Modules/Pester/en-US/about_Mocking.help.txt
        usr/bin/Modules/Pester/en-US/about_Pester.help.txt
        usr/bin/Modules/Pester/en-US/about_TestDrive.help.txt
        usr/bin/Modules/Pester/en-US/about_should.help.txt
        usr/bin/Modules/Pester/nunit_schema_2.5.xsd
        usr/bin/Modules/Pester/vendor
        usr/bin/Modules/Pester/vendor/packages.config
        usr/bin/Modules/Pester/vendor/tools
        usr/bin/Modules/Pester/vendor/tools/NuGet.exe
        usr/bin/Modules/Pester/vendor/tools/OneGet
        usr/bin/Modules/Pester/vendor/tools/OneGet/Etc
        usr/bin/Modules/Pester/vendor/tools/OneGet/Etc/PackageProviderFunctions.psm1
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.MetaProvider.PowerShell.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.PackageProvider.Bootstrap.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.ServicesProvider.Common.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.Utility.PowerShell.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.Utility.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.OneGet.exe
        usr/bin/Modules/Pester/vendor/tools/OneGet/Microsoft.PowerShell.OneGet.dll
        usr/bin/Modules/Pester/vendor/tools/OneGet/OneGet.format.ps1xml
        usr/bin/Modules/Pester/vendor/tools/OneGet/OneGet.psd1
        usr/bin/Modules/Pester/vendor/tools/OneGet/OneGet_4ae9fd46-338a-459c-8186-07f910774cb8_HelpInfo.xml
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/PSGet.Format.ps1xml
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/PSGet.Resource.psd1
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/PSGet.psm1
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/PowerShellGet.psd1
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/PowerShellGet_1d73a601-4a6c-43c5-ba3f-619b18bbb404_HelpInfo.xml
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/en-US
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/en-US/PSGet.Resource.psd1
        usr/bin/Modules/Pester/vendor/tools/PowerShellGet/en-US/PSGet.psm1-help.xml
        usr/bin/Modules/PowerShellGet
        usr/bin/Modules/PowerShellGet/1.1.3.2
        usr/bin/Modules/PowerShellGet/1.1.3.2/PSGet.Format.ps1xml
        usr/bin/Modules/PowerShellGet/1.1.3.2/PSGet.Resource.psd1
        usr/bin/Modules/PowerShellGet/1.1.3.2/PSModule.psm1
        usr/bin/Modules/PowerShellGet/1.1.3.2/PowerShellGet.cat
        usr/bin/Modules/PowerShellGet/1.1.3.2/PowerShellGet.psd1
        usr/bin/Modules/PowerShellGet/1.1.3.2/en-US
        usr/bin/Modules/PowerShellGet/1.1.3.2/en-US/PSGet.Resource.psd1
        usr/bin/Newtonsoft.Json.dll
        usr/bin/SOS.NETCore.dll
        usr/bin/System.AppContext.dll
        usr/bin/System.Buffers.dll
        usr/bin/System.Collections.Concurrent.dll
        usr/bin/System.Collections.Immutable.dll
        usr/bin/System.Collections.NonGeneric.dll
        usr/bin/System.Collections.Specialized.dll
        usr/bin/System.Collections.dll
        usr/bin/System.ComponentModel.Annotations.dll
        usr/bin/System.ComponentModel.Composition.dll
        usr/bin/System.ComponentModel.DataAnnotations.dll
        usr/bin/System.ComponentModel.EventBasedAsync.dll
        usr/bin/System.ComponentModel.Primitives.dll
        usr/bin/System.ComponentModel.TypeConverter.dll
        usr/bin/System.ComponentModel.dll
        usr/bin/System.Configuration.dll
        usr/bin/System.Console.dll
        usr/bin/System.Core.dll
        usr/bin/System.Data.Common.dll
        usr/bin/System.Data.SqlClient.dll
        usr/bin/System.Data.dll
        usr/bin/System.Diagnostics.Contracts.dll
        usr/bin/System.Diagnostics.Debug.dll
        usr/bin/System.Diagnostics.DiagnosticSource.dll
        usr/bin/System.Diagnostics.FileVersionInfo.dll
        usr/bin/System.Diagnostics.Process.dll
        usr/bin/System.Diagnostics.StackTrace.dll
        usr/bin/System.Diagnostics.TextWriterTraceListener.dll
        usr/bin/System.Diagnostics.Tools.dll
        usr/bin/System.Diagnostics.TraceSource.dll
        usr/bin/System.Diagnostics.Tracing.dll
        usr/bin/System.Drawing.Primitives.dll
        usr/bin/System.Drawing.dll
        usr/bin/System.Dynamic.Runtime.dll
        usr/bin/System.Globalization.Calendars.dll
        usr/bin/System.Globalization.Extensions.dll
        usr/bin/System.Globalization.Native.so
        usr/bin/System.Globalization.dll
        usr/bin/System.IO.Compression.FileSystem.dll
        usr/bin/System.IO.Compression.Native.so
        usr/bin/System.IO.Compression.ZipFile.dll
        usr/bin/System.IO.Compression.dll
        usr/bin/System.IO.FileSystem.AccessControl.dll
        usr/bin/System.IO.FileSystem.DriveInfo.dll
        usr/bin/System.IO.FileSystem.Primitives.dll
        usr/bin/System.IO.FileSystem.Watcher.dll
        usr/bin/System.IO.FileSystem.dll
        usr/bin/System.IO.IsolatedStorage.dll
        usr/bin/System.IO.MemoryMappedFiles.dll
        usr/bin/System.IO.Packaging.dll
        usr/bin/System.IO.Pipes.dll
        usr/bin/System.IO.UnmanagedMemoryStream.dll
        usr/bin/System.IO.dll
        usr/bin/System.Linq.Expressions.dll
        usr/bin/System.Linq.Parallel.dll
        usr/bin/System.Linq.Queryable.dll
        usr/bin/System.Linq.dll
        usr/bin/System.Management.Automation.dll
        usr/bin/System.Management.Automation.xml
        usr/bin/System.Native.a
        usr/bin/System.Native.so
        usr/bin/System.Net.Http.Native.so
        usr/bin/System.Net.Http.WinHttpHandler.dll
        usr/bin/System.Net.Http.dll
        usr/bin/System.Net.HttpListener.dll
        usr/bin/System.Net.Mail.dll
        usr/bin/System.Net.NameResolution.dll
        usr/bin/System.Net.NetworkInformation.dll
        usr/bin/System.Net.Ping.dll
        usr/bin/System.Net.Primitives.dll
        usr/bin/System.Net.Requests.dll
        usr/bin/System.Net.Security.Native.so
        usr/bin/System.Net.Security.dll
        usr/bin/System.Net.ServicePoint.dll
        usr/bin/System.Net.Sockets.dll
        usr/bin/System.Net.WebClient.dll
        usr/bin/System.Net.WebHeaderCollection.dll
        usr/bin/System.Net.WebProxy.dll
        usr/bin/System.Net.WebSockets.Client.dll
        usr/bin/System.Net.WebSockets.dll
        usr/bin/System.Net.dll
        usr/bin/System.Numerics.Vectors.dll
        usr/bin/System.Numerics.dll
        usr/bin/System.ObjectModel.dll
        usr/bin/System.Private.CoreLib.dll
        usr/bin/System.Private.DataContractSerialization.dll
        usr/bin/System.Private.ServiceModel.dll
        usr/bin/System.Private.Uri.dll
        usr/bin/System.Private.Xml.Linq.dll
        usr/bin/System.Private.Xml.dll
        usr/bin/System.Reflection.DispatchProxy.dll
        usr/bin/System.Reflection.Emit.ILGeneration.dll
        usr/bin/System.Reflection.Emit.Lightweight.dll
        usr/bin/System.Reflection.Emit.dll
        usr/bin/System.Reflection.Extensions.dll
        usr/bin/System.Reflection.Metadata.dll
        usr/bin/System.Reflection.Primitives.dll
        usr/bin/System.Reflection.TypeExtensions.dll
        usr/bin/System.Reflection.dll
        usr/bin/System.Resources.Reader.dll
        usr/bin/System.Resources.ResourceManager.dll
        usr/bin/System.Resources.Writer.dll
        usr/bin/System.Runtime.CompilerServices.VisualC.dll
        usr/bin/System.Runtime.Extensions.dll
        usr/bin/System.Runtime.Handles.dll
        usr/bin/System.Runtime.InteropServices.RuntimeInformation.dll
        usr/bin/System.Runtime.InteropServices.WindowsRuntime.dll
        usr/bin/System.Runtime.InteropServices.dll
        usr/bin/System.Runtime.Loader.dll
        usr/bin/System.Runtime.Numerics.dll
        usr/bin/System.Runtime.Serialization.Formatters.dll
        usr/bin/System.Runtime.Serialization.Json.dll
        usr/bin/System.Runtime.Serialization.Primitives.dll
        usr/bin/System.Runtime.Serialization.Xml.dll
        usr/bin/System.Runtime.Serialization.dll
        usr/bin/System.Runtime.dll
        usr/bin/System.Security.AccessControl.dll
        usr/bin/System.Security.Claims.dll
        usr/bin/System.Security.Cryptography.Algorithms.dll
        usr/bin/System.Security.Cryptography.Cng.dll
        usr/bin/System.Security.Cryptography.Csp.dll
        usr/bin/System.Security.Cryptography.Encoding.dll
        usr/bin/System.Security.Cryptography.Native.OpenSsl.so
        usr/bin/System.Security.Cryptography.OpenSsl.dll
        usr/bin/System.Security.Cryptography.Pkcs.dll
        usr/bin/System.Security.Cryptography.Primitives.dll
        usr/bin/System.Security.Cryptography.X509Certificates.dll
        usr/bin/System.Security.Permissions.dll
        usr/bin/System.Security.Principal.Windows.dll
        usr/bin/System.Security.Principal.dll
        usr/bin/System.Security.SecureString.dll
        usr/bin/System.Security.dll
        usr/bin/System.ServiceModel.Duplex.dll
        usr/bin/System.ServiceModel.Http.dll
        usr/bin/System.ServiceModel.NetTcp.dll
        usr/bin/System.ServiceModel.Primitives.dll
        usr/bin/System.ServiceModel.Security.dll
        usr/bin/System.ServiceModel.Web.dll
        usr/bin/System.ServiceProcess.ServiceController.dll
        usr/bin/System.ServiceProcess.dll
        usr/bin/System.Text.Encoding.CodePages.dll
        usr/bin/System.Text.Encoding.Extensions.dll
        usr/bin/System.Text.Encoding.dll
        usr/bin/System.Text.Encodings.Web.dll
        usr/bin/System.Text.RegularExpressions.dll
        usr/bin/System.Threading.AccessControl.dll
        usr/bin/System.Threading.Overlapped.dll
        usr/bin/System.Threading.Tasks.Dataflow.dll
        usr/bin/System.Threading.Tasks.Extensions.dll
        usr/bin/System.Threading.Tasks.Parallel.dll
        usr/bin/System.Threading.Tasks.dll
        usr/bin/System.Threading.Thread.dll
        usr/bin/System.Threading.ThreadPool.dll
        usr/bin/System.Threading.Timer.dll
        usr/bin/System.Threading.dll
        usr/bin/System.Transactions.Local.dll
        usr/bin/System.Transactions.dll
        usr/bin/System.ValueTuple.dll
        usr/bin/System.Web.HttpUtility.dll
        usr/bin/System.Web.dll
        usr/bin/System.Windows.dll
        usr/bin/System.Xml.Linq.dll
        usr/bin/System.Xml.ReaderWriter.dll
        usr/bin/System.Xml.Serialization.dll
        usr/bin/System.Xml.XDocument.dll
        usr/bin/System.Xml.XPath.XDocument.dll
        usr/bin/System.Xml.XPath.dll
        usr/bin/System.Xml.XmlDocument.dll
        usr/bin/System.Xml.XmlSerializer.dll
        usr/bin/System.Xml.dll
        usr/bin/System.dll
        usr/bin/WindowsBase.dll
        usr/bin/chage
        usr/bin/chfn
        usr/bin/chsh
        usr/bin/createdump
        usr/bin/debconf
        usr/bin/debconf-apt-progress
        usr/bin/debconf-communicate
        usr/bin/debconf-copydb
        usr/bin/debconf-escape
        usr/bin/debconf-set-selections
        usr/bin/debconf-show
        usr/bin/dpkg
        usr/bin/dpkg-deb
        usr/bin/dpkg-divert
        usr/bin/dpkg-maintscript-helper
        usr/bin/dpkg-query
        usr/bin/dpkg-split
        usr/bin/dpkg-statoverride
        usr/bin/dpkg-trigger
        usr/bin/en-US
        usr/bin/en-US/Microsoft.PowerShell.Commands.Management.dll-help.xml
        usr/bin/en-US/Microsoft.PowerShell.Commands.Utility.dll-help.xml
        usr/bin/en-US/Microsoft.PowerShell.ConsoleHost.dll-help.xml
        usr/bin/en-US/Microsoft.PowerShell.Security.dll-help.xml
        usr/bin/en-US/Microsoft.PowerShell.Utility.psm1-help.xml
        usr/bin/en-US/Microsoft.Powershell.Management.dll-help.xml
        usr/bin/en-US/System.Management.Automation.dll-help.xml
        usr/bin/en-US/about_Aliases.help.txt
        usr/bin/en-US/about_Arithmetic_Operators.help.txt
        usr/bin/en-US/about_Arrays.help.txt
        usr/bin/en-US/about_Assignment_Operators.help.txt
        usr/bin/en-US/about_Automatic_Variables.help.txt
        usr/bin/en-US/about_Break.help.txt
        usr/bin/en-US/about_Classes.help.txt
        usr/bin/en-US/about_Command_Precedence.help.txt
        usr/bin/en-US/about_Command_Syntax.help.txt
        usr/bin/en-US/about_Comment_Based_Help.help.txt
        usr/bin/en-US/about_CommonParameters.help.txt
        usr/bin/en-US/about_Comparison_Operators.help.txt
        usr/bin/en-US/about_Continue.help.txt
        usr/bin/en-US/about_Core_Commands.help.txt
        usr/bin/en-US/about_Data_Sections.help.txt
        usr/bin/en-US/about_Debuggers.help.txt
        usr/bin/en-US/about_DesiredStateConfiguration.help.txt
        usr/bin/en-US/about_Do.help.txt
        usr/bin/en-US/about_Environment_Variables.help.txt
        usr/bin/en-US/about_Escape_Characters.help.txt
        usr/bin/en-US/about_Eventlogs.help.txt
        usr/bin/en-US/about_Execution_Policies.help.txt
        usr/bin/en-US/about_For.help.txt
        usr/bin/en-US/about_ForEach.help.txt
        usr/bin/en-US/about_Format.ps1xml.help.txt
        usr/bin/en-US/about_Functions.help.txt
        usr/bin/en-US/about_Functions_Advanced.help.txt
        usr/bin/en-US/about_Functions_Advanced_Methods.help.txt
        usr/bin/en-US/about_Functions_Advanced_Parameters.help.txt
        usr/bin/en-US/about_Functions_CmdletBindingAttribute.help.txt
        usr/bin/en-US/about_Functions_OutputTypeAttribute.help.txt
        usr/bin/en-US/about_Group_Policy_Settings.help.txt
        usr/bin/en-US/about_Hash_Tables.help.txt
        usr/bin/en-US/about_Hidden.help.txt
        usr/bin/en-US/about_History.help.txt
        usr/bin/en-US/about_If.help.txt
        usr/bin/en-US/about_Job_Details.help.txt
        usr/bin/en-US/about_Jobs.help.txt
        usr/bin/en-US/about_Join.help.txt
        usr/bin/en-US/about_Language_Keywords.help.txt
        usr/bin/en-US/about_Language_Modes.help.txt
        usr/bin/en-US/about_Line_Editing.help.txt
        usr/bin/en-US/about_Locations.help.txt
        usr/bin/en-US/about_Logical_Operators.help.txt
        usr/bin/en-US/about_Methods.help.txt
        usr/bin/en-US/about_Modules.help.txt
        usr/bin/en-US/about_Object_Creation.help.txt
        usr/bin/en-US/about_Objects.help.txt
        usr/bin/en-US/about_Operator_Precedence.help.txt
        usr/bin/en-US/about_Operators.help.txt
        usr/bin/en-US/about_PSConsoleHostReadLine.help.txt
        usr/bin/en-US/about_PSReadline.help.txt
        usr/bin/en-US/about_PSSession_Details.help.txt
        usr/bin/en-US/about_PSSessions.help.txt
        usr/bin/en-US/about_PSSnapins.help.txt
        usr/bin/en-US/about_PackageManagement.help.txt
        usr/bin/en-US/about_Parameters.help.txt
        usr/bin/en-US/about_Parameters_Default_Values.help.txt
        usr/bin/en-US/about_Parsing.help.txt
        usr/bin/en-US/about_Path_Syntax.help.txt
        usr/bin/en-US/about_Pipelines.help.txt
        usr/bin/en-US/about_PowerShell.exe.help.txt
        usr/bin/en-US/about_PowerShell_Ise.exe.help.txt
        usr/bin/en-US/about_Preference_Variables.help.txt
        usr/bin/en-US/about_Profiles.help.txt
        usr/bin/en-US/about_Prompts.help.txt
        usr/bin/en-US/about_Properties.help.txt
        usr/bin/en-US/about_Providers.help.txt
        usr/bin/en-US/about_Quoting_Rules.help.txt
        usr/bin/en-US/about_Redirection.help.txt
        usr/bin/en-US/about_Ref.help.txt
        usr/bin/en-US/about_Regular_Expressions.help.txt
        usr/bin/en-US/about_Remote.help.txt
        usr/bin/en-US/about_Remote_Disconnected_Sessions.help.txt
        usr/bin/en-US/about_Remote_FAQ.help.txt
        usr/bin/en-US/about_Remote_Jobs.help.txt
        usr/bin/en-US/about_Remote_Output.help.txt
        usr/bin/en-US/about_Remote_Requirements.help.txt
        usr/bin/en-US/about_Remote_Troubleshooting.help.txt
        usr/bin/en-US/about_Remote_Variables.help.txt
        usr/bin/en-US/about_Requires.help.txt
        usr/bin/en-US/about_Reserved_Words.help.txt
        usr/bin/en-US/about_Return.help.txt
        usr/bin/en-US/about_Run_With_PowerShell.help.txt
        usr/bin/en-US/about_Scopes.help.txt
        usr/bin/en-US/about_Script_Blocks.help.txt
        usr/bin/en-US/about_Script_Internationalization.help.txt
        usr/bin/en-US/about_Scripts.help.txt
        usr/bin/en-US/about_Session_Configuration_Files.help.txt
        usr/bin/en-US/about_Session_Configurations.help.txt
        usr/bin/en-US/about_Signing.help.txt
        usr/bin/en-US/about_Special_Characters.help.txt
        usr/bin/en-US/about_Splatting.help.txt
        usr/bin/en-US/about_Split.help.txt
        usr/bin/en-US/about_Switch.help.txt
        usr/bin/en-US/about_Throw.help.txt
        usr/bin/en-US/about_Transactions.help.txt
        usr/bin/en-US/about_Trap.help.txt
        usr/bin/en-US/about_Try_Catch_Finally.help.txt
        usr/bin/en-US/about_Type_Operators.help.txt
        usr/bin/en-US/about_Types.ps1xml.help.txt
        usr/bin/en-US/about_Updatable_Help.help.txt
        usr/bin/en-US/about_Variables.help.txt
        usr/bin/en-US/about_WMI.help.txt
        usr/bin/en-US/about_WMI_Cmdlets.help.txt
        usr/bin/en-US/about_WQL.help.txt
        usr/bin/en-US/about_WS-Management_Cmdlets.help.txt
        usr/bin/en-US/about_While.help.txt
        usr/bin/en-US/about_Wildcards.help.txt
        usr/bin/en-US/about_Windows_PowerShell_5.0.help.txt
        usr/bin/en-US/about_Windows_PowerShell_ISE.help.txt
        usr/bin/en-US/about_Windows_RT.help.txt
        usr/bin/en-US/default.help.txt
        usr/bin/expiry
        usr/bin/gpasswd
        usr/bin/ischroot
        usr/bin/libclrjit.so
        usr/bin/libcoreclr.so
        usr/bin/libcoreclrtraceptprovider.so
        usr/bin/libdbgshim.so
        usr/bin/libhostfxr.so
        usr/bin/libhostpolicy.so
        usr/bin/libmi.so
        usr/bin/libmscordaccore.so
        usr/bin/libmscordbi.so
        usr/bin/libpsl-native.so
        usr/bin/libpsrpclient.so
        usr/bin/libsos.so
        usr/bin/libsosplugin.so
        usr/bin/license_thirdparty_proprietary.txt
        usr/bin/mscorlib.dll
        usr/bin/netstandard.dll
        usr/bin/passwd
        usr/bin/perl
        usr/bin/perl5.18.2
        usr/bin/powershell
        usr/bin/powershell.deps.json
        usr/bin/powershell.dll
        usr/bin/powershell.pdb
        usr/bin/powershell.runtimeconfig.json
        usr/bin/powershell.version
        usr/bin/powershell.wrapper
        usr/bin/powershell.xml
        usr/bin/ref
        usr/bin/ref/Microsoft.CSharp.dll
        usr/bin/ref/Microsoft.VisualBasic.dll
        usr/bin/ref/Microsoft.Win32.Primitives.dll
        usr/bin/ref/System.AppContext.dll
        usr/bin/ref/System.Buffers.dll
        usr/bin/ref/System.Collections.Concurrent.dll
        usr/bin/ref/System.Collections.Immutable.dll
        usr/bin/ref/System.Collections.NonGeneric.dll
        usr/bin/ref/System.Collections.Specialized.dll
        usr/bin/ref/System.Collections.dll
        usr/bin/ref/System.ComponentModel.Annotations.dll
        usr/bin/ref/System.ComponentModel.Composition.dll
        usr/bin/ref/System.ComponentModel.DataAnnotations.dll
        usr/bin/ref/System.ComponentModel.EventBasedAsync.dll
        usr/bin/ref/System.ComponentModel.Primitives.dll
        usr/bin/ref/System.ComponentModel.TypeConverter.dll
        usr/bin/ref/System.ComponentModel.dll
        usr/bin/ref/System.Configuration.dll
        usr/bin/ref/System.Console.dll
        usr/bin/ref/System.Core.dll
        usr/bin/ref/System.Data.Common.dll
        usr/bin/ref/System.Data.dll
        usr/bin/ref/System.Diagnostics.Contracts.dll
        usr/bin/ref/System.Diagnostics.Debug.dll
        usr/bin/ref/System.Diagnostics.DiagnosticSource.dll
        usr/bin/ref/System.Diagnostics.FileVersionInfo.dll
        usr/bin/ref/System.Diagnostics.Process.dll
        usr/bin/ref/System.Diagnostics.StackTrace.dll
        usr/bin/ref/System.Diagnostics.TextWriterTraceListener.dll
        usr/bin/ref/System.Diagnostics.Tools.dll
        usr/bin/ref/System.Diagnostics.TraceSource.dll
        usr/bin/ref/System.Diagnostics.Tracing.dll
        usr/bin/ref/System.Drawing.Primitives.dll
        usr/bin/ref/System.Drawing.dll
        usr/bin/ref/System.Dynamic.Runtime.dll
        usr/bin/ref/System.Globalization.Calendars.dll
        usr/bin/ref/System.Globalization.Extensions.dll
        usr/bin/ref/System.Globalization.dll
        usr/bin/ref/System.IO.Compression.FileSystem.dll
        usr/bin/ref/System.IO.Compression.ZipFile.dll
        usr/bin/ref/System.IO.Compression.dll
        usr/bin/ref/System.IO.FileSystem.DriveInfo.dll
        usr/bin/ref/System.IO.FileSystem.Primitives.dll
        usr/bin/ref/System.IO.FileSystem.Watcher.dll
        usr/bin/ref/System.IO.FileSystem.dll
        usr/bin/ref/System.IO.IsolatedStorage.dll
        usr/bin/ref/System.IO.MemoryMappedFiles.dll
        usr/bin/ref/System.IO.Pipes.dll
        usr/bin/ref/System.IO.UnmanagedMemoryStream.dll
        usr/bin/ref/System.IO.dll
        usr/bin/ref/System.Linq.Expressions.dll
        usr/bin/ref/System.Linq.Parallel.dll
        usr/bin/ref/System.Linq.Queryable.dll
        usr/bin/ref/System.Linq.dll
        usr/bin/ref/System.Net.Http.dll
        usr/bin/ref/System.Net.HttpListener.dll
        usr/bin/ref/System.Net.Mail.dll
        usr/bin/ref/System.Net.NameResolution.dll
        usr/bin/ref/System.Net.NetworkInformation.dll
        usr/bin/ref/System.Net.Ping.dll
        usr/bin/ref/System.Net.Primitives.dll
        usr/bin/ref/System.Net.Requests.dll
        usr/bin/ref/System.Net.Security.dll
        usr/bin/ref/System.Net.ServicePoint.dll
        usr/bin/ref/System.Net.Sockets.dll
        usr/bin/ref/System.Net.WebClient.dll
        usr/bin/ref/System.Net.WebHeaderCollection.dll
        usr/bin/ref/System.Net.WebProxy.dll
        usr/bin/ref/System.Net.WebSockets.Client.dll
        usr/bin/ref/System.Net.WebSockets.dll
        usr/bin/ref/System.Net.dll
        usr/bin/ref/System.Numerics.Vectors.dll
        usr/bin/ref/System.Numerics.dll
        usr/bin/ref/System.ObjectModel.dll
        usr/bin/ref/System.Reflection.DispatchProxy.dll
        usr/bin/ref/System.Reflection.Emit.ILGeneration.dll
        usr/bin/ref/System.Reflection.Emit.Lightweight.dll
        usr/bin/ref/System.Reflection.Emit.dll
        usr/bin/ref/System.Reflection.Extensions.dll
        usr/bin/ref/System.Reflection.Metadata.dll
        usr/bin/ref/System.Reflection.Primitives.dll
        usr/bin/ref/System.Reflection.TypeExtensions.dll
        usr/bin/ref/System.Reflection.dll
        usr/bin/ref/System.Resources.Reader.dll
        usr/bin/ref/System.Resources.ResourceManager.dll
        usr/bin/ref/System.Resources.Writer.dll
        usr/bin/ref/System.Runtime.CompilerServices.VisualC.dll
        usr/bin/ref/System.Runtime.Extensions.dll
        usr/bin/ref/System.Runtime.Handles.dll
        usr/bin/ref/System.Runtime.InteropServices.RuntimeInformation.dll
        usr/bin/ref/System.Runtime.InteropServices.WindowsRuntime.dll
        usr/bin/ref/System.Runtime.InteropServices.dll
        usr/bin/ref/System.Runtime.Loader.dll
        usr/bin/ref/System.Runtime.Numerics.dll
        usr/bin/ref/System.Runtime.Serialization.Formatters.dll
        usr/bin/ref/System.Runtime.Serialization.Json.dll
        usr/bin/ref/System.Runtime.Serialization.Primitives.dll
        usr/bin/ref/System.Runtime.Serialization.Xml.dll
        usr/bin/ref/System.Runtime.Serialization.dll
        usr/bin/ref/System.Runtime.dll
        usr/bin/ref/System.Security.Claims.dll
        usr/bin/ref/System.Security.Cryptography.Algorithms.dll
        usr/bin/ref/System.Security.Cryptography.Csp.dll
        usr/bin/ref/System.Security.Cryptography.Encoding.dll
        usr/bin/ref/System.Security.Cryptography.Primitives.dll
        usr/bin/ref/System.Security.Cryptography.X509Certificates.dll
        usr/bin/ref/System.Security.Principal.dll
        usr/bin/ref/System.Security.SecureString.dll
        usr/bin/ref/System.Security.dll
        usr/bin/ref/System.ServiceModel.Web.dll
        usr/bin/ref/System.ServiceProcess.dll
        usr/bin/ref/System.Text.Encoding.Extensions.dll
        usr/bin/ref/System.Text.Encoding.dll
        usr/bin/ref/System.Text.RegularExpressions.dll
        usr/bin/ref/System.Threading.Overlapped.dll
        usr/bin/ref/System.Threading.Tasks.Dataflow.dll
        usr/bin/ref/System.Threading.Tasks.Extensions.dll
        usr/bin/ref/System.Threading.Tasks.Parallel.dll
        usr/bin/ref/System.Threading.Tasks.dll
        usr/bin/ref/System.Threading.Thread.dll
        usr/bin/ref/System.Threading.ThreadPool.dll
        usr/bin/ref/System.Threading.Timer.dll
        usr/bin/ref/System.Threading.dll
        usr/bin/ref/System.Transactions.Local.dll
        usr/bin/ref/System.Transactions.dll
        usr/bin/ref/System.ValueTuple.dll
        usr/bin/ref/System.Web.HttpUtility.dll
        usr/bin/ref/System.Web.dll
        usr/bin/ref/System.Windows.dll
        usr/bin/ref/System.Xml.Linq.dll
        usr/bin/ref/System.Xml.ReaderWriter.dll
        usr/bin/ref/System.Xml.Serialization.dll
        usr/bin/ref/System.Xml.XDocument.dll
        usr/bin/ref/System.Xml.XPath.XDocument.dll
        usr/bin/ref/System.Xml.XPath.dll
        usr/bin/ref/System.Xml.XmlDocument.dll
        usr/bin/ref/System.Xml.XmlSerializer.dll
        usr/bin/ref/System.Xml.dll
        usr/bin/ref/System.dll
        usr/bin/ref/WindowsBase.dll
        usr/bin/ref/mscorlib.dll
        usr/bin/ref/netstandard.dll
        usr/bin/savelog
        usr/bin/select-editor
        usr/bin/sensible-browser
        usr/bin/sensible-editor
        usr/bin/sensible-pager
        usr/bin/sosdocsunix.txt
        usr/bin/update-alternatives
        usr/bin/which
        usr/lib
        usr/lib/audit
        usr/lib/audit/sotruss-lib.so
        usr/lib/gcc
        usr/lib/gcc/x86_64-linux-gnu
        usr/lib/gcc/x86_64-linux-gnu/4.8
        usr/lib/gcc/x86_64-linux-gnu/4.8.2
        usr/lib/gcc/x86_64-linux-gnu/4.9
        usr/lib/gcc/x86_64-linux-gnu/4.9.0
        usr/lib/gconv
        usr/lib/gconv/ANSI_X3.110.so
        usr/lib/gconv/ARMSCII-8.so
        usr/lib/gconv/ASMO_449.so
        usr/lib/gconv/BIG5.so
        usr/lib/gconv/BIG5HKSCS.so
        usr/lib/gconv/BRF.so
        usr/lib/gconv/CP10007.so
        usr/lib/gconv/CP1125.so
        usr/lib/gconv/CP1250.so
        usr/lib/gconv/CP1251.so
        usr/lib/gconv/CP1252.so
        usr/lib/gconv/CP1253.so
        usr/lib/gconv/CP1254.so
        usr/lib/gconv/CP1255.so
        usr/lib/gconv/CP1256.so
        usr/lib/gconv/CP1257.so
        usr/lib/gconv/CP1258.so
        usr/lib/gconv/CP737.so
        usr/lib/gconv/CP770.so
        usr/lib/gconv/CP771.so
        usr/lib/gconv/CP772.so
        usr/lib/gconv/CP773.so
        usr/lib/gconv/CP774.so
        usr/lib/gconv/CP775.so
        usr/lib/gconv/CP932.so
        usr/lib/gconv/CSN_369103.so
        usr/lib/gconv/CWI.so
        usr/lib/gconv/DEC-MCS.so
        usr/lib/gconv/EBCDIC-AT-DE-A.so
        usr/lib/gconv/EBCDIC-AT-DE.so
        usr/lib/gconv/EBCDIC-CA-FR.so
        usr/lib/gconv/EBCDIC-DK-NO-A.so
        usr/lib/gconv/EBCDIC-DK-NO.so
        usr/lib/gconv/EBCDIC-ES-A.so
        usr/lib/gconv/EBCDIC-ES-S.so
        usr/lib/gconv/EBCDIC-ES.so
        usr/lib/gconv/EBCDIC-FI-SE-A.so
        usr/lib/gconv/EBCDIC-FI-SE.so
        usr/lib/gconv/EBCDIC-FR.so
        usr/lib/gconv/EBCDIC-IS-FRISS.so
        usr/lib/gconv/EBCDIC-IT.so
        usr/lib/gconv/EBCDIC-PT.so
        usr/lib/gconv/EBCDIC-UK.so
        usr/lib/gconv/EBCDIC-US.so
        usr/lib/gconv/ECMA-CYRILLIC.so
        usr/lib/gconv/EUC-CN.so
        usr/lib/gconv/EUC-JISX0213.so
        usr/lib/gconv/EUC-JP-MS.so
        usr/lib/gconv/EUC-JP.so
        usr/lib/gconv/EUC-KR.so
        usr/lib/gconv/EUC-TW.so
        usr/lib/gconv/GB18030.so
        usr/lib/gconv/GBBIG5.so
        usr/lib/gconv/GBGBK.so
        usr/lib/gconv/GBK.so
        usr/lib/gconv/GEORGIAN-ACADEMY.so
        usr/lib/gconv/GEORGIAN-PS.so
        usr/lib/gconv/GOST_19768-74.so
        usr/lib/gconv/GREEK-CCITT.so
        usr/lib/gconv/GREEK7-OLD.so
        usr/lib/gconv/GREEK7.so
        usr/lib/gconv/HP-GREEK8.so
        usr/lib/gconv/HP-ROMAN8.so
        usr/lib/gconv/HP-ROMAN9.so
        usr/lib/gconv/HP-THAI8.so
        usr/lib/gconv/HP-TURKISH8.so
        usr/lib/gconv/IBM037.so
        usr/lib/gconv/IBM038.so
        usr/lib/gconv/IBM1004.so
        usr/lib/gconv/IBM1008.so
        usr/lib/gconv/IBM1008_420.so
        usr/lib/gconv/IBM1025.so
        usr/lib/gconv/IBM1026.so
        usr/lib/gconv/IBM1046.so
        usr/lib/gconv/IBM1047.so
        usr/lib/gconv/IBM1097.so
        usr/lib/gconv/IBM1112.so
        usr/lib/gconv/IBM1122.so
        usr/lib/gconv/IBM1123.so
        usr/lib/gconv/IBM1124.so
        usr/lib/gconv/IBM1129.so
        usr/lib/gconv/IBM1130.so
        usr/lib/gconv/IBM1132.so
        usr/lib/gconv/IBM1133.so
        usr/lib/gconv/IBM1137.so
        usr/lib/gconv/IBM1140.so
        usr/lib/gconv/IBM1141.so
        usr/lib/gconv/IBM1142.so
        usr/lib/gconv/IBM1143.so
        usr/lib/gconv/IBM1144.so
        usr/lib/gconv/IBM1145.so
        usr/lib/gconv/IBM1146.so
        usr/lib/gconv/IBM1147.so
        usr/lib/gconv/IBM1148.so
        usr/lib/gconv/IBM1149.so
        usr/lib/gconv/IBM1153.so
        usr/lib/gconv/IBM1154.so
        usr/lib/gconv/IBM1155.so
        usr/lib/gconv/IBM1156.so
        usr/lib/gconv/IBM1157.so
        usr/lib/gconv/IBM1158.so
        usr/lib/gconv/IBM1160.so
        usr/lib/gconv/IBM1161.so
        usr/lib/gconv/IBM1162.so
        usr/lib/gconv/IBM1163.so
        usr/lib/gconv/IBM1164.so
        usr/lib/gconv/IBM1166.so
        usr/lib/gconv/IBM1167.so
        usr/lib/gconv/IBM12712.so
        usr/lib/gconv/IBM1364.so
        usr/lib/gconv/IBM1371.so
        usr/lib/gconv/IBM1388.so
        usr/lib/gconv/IBM1390.so
        usr/lib/gconv/IBM1399.so
        usr/lib/gconv/IBM16804.so
        usr/lib/gconv/IBM256.so
        usr/lib/gconv/IBM273.so
        usr/lib/gconv/IBM274.so
        usr/lib/gconv/IBM275.so
        usr/lib/gconv/IBM277.so
        usr/lib/gconv/IBM278.so
        usr/lib/gconv/IBM280.so
        usr/lib/gconv/IBM281.so
        usr/lib/gconv/IBM284.so
        usr/lib/gconv/IBM285.so
        usr/lib/gconv/IBM290.so
        usr/lib/gconv/IBM297.so
        usr/lib/gconv/IBM420.so
        usr/lib/gconv/IBM423.so
        usr/lib/gconv/IBM424.so
        usr/lib/gconv/IBM437.so
        usr/lib/gconv/IBM4517.so
        usr/lib/gconv/IBM4899.so
        usr/lib/gconv/IBM4909.so
        usr/lib/gconv/IBM4971.so
        usr/lib/gconv/IBM500.so
        usr/lib/gconv/IBM5347.so
        usr/lib/gconv/IBM803.so
        usr/lib/gconv/IBM850.so
        usr/lib/gconv/IBM851.so
        usr/lib/gconv/IBM852.so
        usr/lib/gconv/IBM855.so
        usr/lib/gconv/IBM856.so
        usr/lib/gconv/IBM857.so
        usr/lib/gconv/IBM860.so
        usr/lib/gconv/IBM861.so
        usr/lib/gconv/IBM862.so
        usr/lib/gconv/IBM863.so
        usr/lib/gconv/IBM864.so
        usr/lib/gconv/IBM865.so
        usr/lib/gconv/IBM866.so
        usr/lib/gconv/IBM866NAV.so
        usr/lib/gconv/IBM868.so
        usr/lib/gconv/IBM869.so
        usr/lib/gconv/IBM870.so
        usr/lib/gconv/IBM871.so
        usr/lib/gconv/IBM874.so
        usr/lib/gconv/IBM875.so
        usr/lib/gconv/IBM880.so
        usr/lib/gconv/IBM891.so
        usr/lib/gconv/IBM901.so
        usr/lib/gconv/IBM902.so
        usr/lib/gconv/IBM903.so
        usr/lib/gconv/IBM9030.so
        usr/lib/gconv/IBM904.so
        usr/lib/gconv/IBM905.so
        usr/lib/gconv/IBM9066.so
        usr/lib/gconv/IBM918.so
        usr/lib/gconv/IBM921.so
        usr/lib/gconv/IBM922.so
        usr/lib/gconv/IBM930.so
        usr/lib/gconv/IBM932.so
        usr/lib/gconv/IBM933.so
        usr/lib/gconv/IBM935.so
        usr/lib/gconv/IBM937.so
        usr/lib/gconv/IBM939.so
        usr/lib/gconv/IBM943.so
        usr/lib/gconv/IBM9448.so
        usr/lib/gconv/IEC_P27-1.so
        usr/lib/gconv/INIS-8.so
        usr/lib/gconv/INIS-CYRILLIC.so
        usr/lib/gconv/INIS.so
        usr/lib/gconv/ISIRI-3342.so
        usr/lib/gconv/ISO-2022-CN-EXT.so
        usr/lib/gconv/ISO-2022-CN.so
        usr/lib/gconv/ISO-2022-JP-3.so
        usr/lib/gconv/ISO-2022-JP.so
        usr/lib/gconv/ISO-2022-KR.so
        usr/lib/gconv/ISO-IR-197.so
        usr/lib/gconv/ISO-IR-209.so
        usr/lib/gconv/ISO646.so
        usr/lib/gconv/ISO8859-1.so
        usr/lib/gconv/ISO8859-10.so
        usr/lib/gconv/ISO8859-11.so
        usr/lib/gconv/ISO8859-13.so
        usr/lib/gconv/ISO8859-14.so
        usr/lib/gconv/ISO8859-15.so
        usr/lib/gconv/ISO8859-16.so
        usr/lib/gconv/ISO8859-2.so
        usr/lib/gconv/ISO8859-3.so
        usr/lib/gconv/ISO8859-4.so
        usr/lib/gconv/ISO8859-5.so
        usr/lib/gconv/ISO8859-6.so
        usr/lib/gconv/ISO8859-7.so
        usr/lib/gconv/ISO8859-8.so
        usr/lib/gconv/ISO8859-9.so
        usr/lib/gconv/ISO8859-9E.so
        usr/lib/gconv/ISO_10367-BOX.so
        usr/lib/gconv/ISO_11548-1.so
        usr/lib/gconv/ISO_2033.so
        usr/lib/gconv/ISO_5427-EXT.so
        usr/lib/gconv/ISO_5427.so
        usr/lib/gconv/ISO_5428.so
        usr/lib/gconv/ISO_6937-2.so
        usr/lib/gconv/ISO_6937.so
        usr/lib/gconv/JOHAB.so
        usr/lib/gconv/KOI-8.so
        usr/lib/gconv/KOI8-R.so
        usr/lib/gconv/KOI8-RU.so
        usr/lib/gconv/KOI8-T.so
        usr/lib/gconv/KOI8-U.so
        usr/lib/gconv/LATIN-GREEK-1.so
        usr/lib/gconv/LATIN-GREEK.so
        usr/lib/gconv/MAC-CENTRALEUROPE.so
        usr/lib/gconv/MAC-IS.so
        usr/lib/gconv/MAC-SAMI.so
        usr/lib/gconv/MAC-UK.so
        usr/lib/gconv/MACINTOSH.so
        usr/lib/gconv/MIK.so
        usr/lib/gconv/NATS-DANO.so
        usr/lib/gconv/NATS-SEFI.so
        usr/lib/gconv/PT154.so
        usr/lib/gconv/RK1048.so
        usr/lib/gconv/SAMI-WS2.so
        usr/lib/gconv/SHIFT_JISX0213.so
        usr/lib/gconv/SJIS.so
        usr/lib/gconv/T.61.so
        usr/lib/gconv/TCVN5712-1.so
        usr/lib/gconv/TIS-620.so
        usr/lib/gconv/TSCII.so
        usr/lib/gconv/UHC.so
        usr/lib/gconv/UNICODE.so
        usr/lib/gconv/UTF-16.so
        usr/lib/gconv/UTF-32.so
        usr/lib/gconv/UTF-7.so
        usr/lib/gconv/VISCII.so
        usr/lib/gconv/gconv-modules
        usr/lib/gconv/gconv-modules.cache
        usr/lib/gconv/libCNS.so
        usr/lib/gconv/libGB.so
        usr/lib/gconv/libISOIR165.so
        usr/lib/gconv/libJIS.so
        usr/lib/gconv/libJISX0213.so
        usr/lib/gconv/libKSC.so
        usr/lib/krb5
        usr/lib/krb5/plugins
        usr/lib/krb5/plugins/krb5
        usr/lib/ld-2.19.so
        usr/lib/ld-linux-x86-64.so.2
        usr/lib/libBrokenLocale-2.19.so
        usr/lib/libBrokenLocale.so.1
        usr/lib/libSegFault.so
        usr/lib/libacl.so.1
        usr/lib/libacl.so.1.1.0
        usr/lib/libanl-2.19.so
        usr/lib/libanl.so.1
        usr/lib/libasn1.so.8
        usr/lib/libasn1.so.8.0.0
        usr/lib/libattr.so.1
        usr/lib/libattr.so.1.1.0
        usr/lib/libaudit.so.1
        usr/lib/libaudit.so.1.0.0
        usr/lib/libbz2.so.1
        usr/lib/libbz2.so.1.0
        usr/lib/libbz2.so.1.0.4
        usr/lib/libc-2.19.so
        usr/lib/libcidn-2.19.so
        usr/lib/libcidn.so.1
        usr/lib/libcom_err.so.2.1
        usr/lib/libcrypt-2.19.so
        usr/lib/libcrypto.so.1.0.0
        usr/lib/libcurl.so.3
        usr/lib/libcurl.so.4
        usr/lib/libcurl.so.4.3.0
        usr/lib/libdb-5.3.so
        usr/lib/libdl-2.19.so
        usr/lib/libffi.so.6
        usr/lib/libffi.so.6.0.1
        usr/lib/libgcrypt.so.11
        usr/lib/libgcrypt.so.11.8.2
        usr/lib/libgnutls-extra.so.26
        usr/lib/libgnutls-extra.so.26.22.6
        usr/lib/libgnutls.so.26
        usr/lib/libgnutls.so.26.22.6
        usr/lib/libgpg-error.so.0.10.0
        usr/lib/libgssapi.so.3
        usr/lib/libgssapi.so.3.0.0
        usr/lib/libgssapi_krb5.so.2
        usr/lib/libgssapi_krb5.so.2.2
        usr/lib/libhcrypto.so.4
        usr/lib/libhcrypto.so.4.1.0
        usr/lib/libheimbase.so.1
        usr/lib/libheimbase.so.1.0.0
        usr/lib/libheimntlm.so.0
        usr/lib/libheimntlm.so.0.1.0
        usr/lib/libhx509.so.5
        usr/lib/libhx509.so.5.0.0
        usr/lib/libicudata.so.52
        usr/lib/libicudata.so.52.1
        usr/lib/libicui18n.so.52
        usr/lib/libicui18n.so.52.1
        usr/lib/libicuio.so.52
        usr/lib/libicuio.so.52.1
        usr/lib/libicule.so.52
        usr/lib/libicule.so.52.1
        usr/lib/libiculx.so.52
        usr/lib/libiculx.so.52.1
        usr/lib/libicutest.so.52
        usr/lib/libicutest.so.52.1
        usr/lib/libicutu.so.52
        usr/lib/libicutu.so.52.1
        usr/lib/libicuuc.so.52
        usr/lib/libicuuc.so.52.1
        usr/lib/libidn.so.11
        usr/lib/libidn.so.11.6.11
        usr/lib/libk5crypto.so.3
        usr/lib/libk5crypto.so.3.1
        usr/lib/libkeyutils.so.1.4
        usr/lib/libkrb5.so.26
        usr/lib/libkrb5.so.26.0.0
        usr/lib/libkrb5.so.3
        usr/lib/libkrb5.so.3.3
        usr/lib/libkrb5support.so.0
        usr/lib/libkrb5support.so.0.1
        usr/lib/liblber-2.4.so.2
        usr/lib/liblber-2.4.so.2.8.3
        usr/lib/libldap-2.4.so.2
        usr/lib/libldap_r-2.4.so.2
        usr/lib/libldap_r-2.4.so.2.8.3
        usr/lib/liblzma.so.5
        usr/lib/liblzma.so.5.0.0
        usr/lib/libm-2.19.so
        usr/lib/libmemusage.so
        usr/lib/libnsl-2.19.so
        usr/lib/libnsl.so.1
        usr/lib/libnss_compat-2.19.so
        usr/lib/libnss_compat.so.2
        usr/lib/libnss_dns-2.19.so
        usr/lib/libnss_dns.so.2
        usr/lib/libnss_files-2.19.so
        usr/lib/libnss_files.so.2
        usr/lib/libnss_hesiod-2.19.so
        usr/lib/libnss_hesiod.so.2
        usr/lib/libnss_nis-2.19.so
        usr/lib/libnss_nis.so.2
        usr/lib/libnss_nisplus-2.19.so
        usr/lib/libnss_nisplus.so.2
        usr/lib/libp11-kit.so.0
        usr/lib/libp11-kit.so.0.0.0
        usr/lib/libpam.so.0
        usr/lib/libpam.so.0.83.1
        usr/lib/libpam_misc.so.0
        usr/lib/libpam_misc.so.0.82.0
        usr/lib/libpamc.so.0
        usr/lib/libpamc.so.0.82.1
        usr/lib/libpcprofile.so
        usr/lib/libpcre.so.3
        usr/lib/libpcre.so.3.13.1
        usr/lib/libpcreposix.so.3
        usr/lib/libpcreposix.so.3.13.1
        usr/lib/libperl.so.5.18
        usr/lib/libperl.so.5.18.2
        usr/lib/libpthread-2.19.so
        usr/lib/libresolv-2.19.so
        usr/lib/libroken.so.18
        usr/lib/libroken.so.18.1.0
        usr/lib/librt-2.19.so
        usr/lib/librtmp.so.0
        usr/lib/libsasl2.so.2
        usr/lib/libsasl2.so.2.0.25
        usr/lib/libsemanage.so.1
        usr/lib/libsepol.so.1
        usr/lib/libsqlite3.so.0
        usr/lib/libsqlite3.so.0.8.6
        usr/lib/libssl.so.1.0.0
        usr/lib/libstdc++.so.6
        usr/lib/libstdc++.so.6.0.19
        usr/lib/libtasn1.so.6
        usr/lib/libtasn1.so.6.2.0
        usr/lib/libthread_db-1.0.so
        usr/lib/libthread_db.so.1
        usr/lib/libtic.so.5
        usr/lib/libtic.so.5.9
        usr/lib/libtinfo.so.5
        usr/lib/libtinfo.so.5.9
        usr/lib/libunwind-coredump.so.0
        usr/lib/libunwind-coredump.so.0.0.0
        usr/lib/libunwind-ptrace.so.0
        usr/lib/libunwind-ptrace.so.0.0.0
        usr/lib/libunwind-x86_64.so.8
        usr/lib/libunwind-x86_64.so.8.0.1
        usr/lib/libunwind.so.8
        usr/lib/libunwind.so.8.0.1
        usr/lib/libustr-1.0.so.1
        usr/lib/libustr-1.0.so.1.0.4
        usr/lib/libutil-2.19.so
        usr/lib/libutil.so.1
        usr/lib/libuuid.so.1.3.0
        usr/lib/libwind.so.0
        usr/lib/libwind.so.0.0.0
        usr/lib/libz.so.1.2.8
        usr/lib/mime
        usr/lib/mime/packages
        usr/lib/mime/packages/sensible-utils
        usr/lib/mime/packages/tar
        usr/lib/openssl-1.0.0
        usr/lib/openssl-1.0.0/engines
        usr/lib/openssl-1.0.0/engines/lib4758cca.so
        usr/lib/openssl-1.0.0/engines/libaep.so
        usr/lib/openssl-1.0.0/engines/libatalla.so
        usr/lib/openssl-1.0.0/engines/libcapi.so
        usr/lib/openssl-1.0.0/engines/libchil.so
        usr/lib/openssl-1.0.0/engines/libcswift.so
        usr/lib/openssl-1.0.0/engines/libgmp.so
        usr/lib/openssl-1.0.0/engines/libgost.so
        usr/lib/openssl-1.0.0/engines/libnuron.so
        usr/lib/openssl-1.0.0/engines/libpadlock.so
        usr/lib/openssl-1.0.0/engines/libsureware.so
        usr/lib/openssl-1.0.0/engines/libubsec.so
        usr/lib/perl
        usr/lib/perl/5.18
        usr/lib/perl/5.18.2
        usr/lib/perl/5.18.2/Config.pm
        usr/lib/perl/5.18.2/Config_git.pl
        usr/lib/perl/5.18.2/Config_heavy.pl
        usr/lib/perl/5.18.2/Cwd.pm
        usr/lib/perl/5.18.2/DynaLoader.pm
        usr/lib/perl/5.18.2/Errno.pm
        usr/lib/perl/5.18.2/Fcntl.pm
        usr/lib/perl/5.18.2/File
        usr/lib/perl/5.18.2/File/Glob.pm
        usr/lib/perl/5.18.2/File/Spec
        usr/lib/perl/5.18.2/File/Spec/Unix.pm
        usr/lib/perl/5.18.2/File/Spec.pm
        usr/lib/perl/5.18.2/Hash
        usr/lib/perl/5.18.2/Hash/Util.pm
        usr/lib/perl/5.18.2/IO
        usr/lib/perl/5.18.2/IO/File.pm
        usr/lib/perl/5.18.2/IO/Handle.pm
        usr/lib/perl/5.18.2/IO/Pipe.pm
        usr/lib/perl/5.18.2/IO/Seekable.pm
        usr/lib/perl/5.18.2/IO/Select.pm
        usr/lib/perl/5.18.2/IO/Socket
        usr/lib/perl/5.18.2/IO/Socket/INET.pm
        usr/lib/perl/5.18.2/IO/Socket/UNIX.pm
        usr/lib/perl/5.18.2/IO/Socket.pm
        usr/lib/perl/5.18.2/IO.pm
        usr/lib/perl/5.18.2/List
        usr/lib/perl/5.18.2/List/Util.pm
        usr/lib/perl/5.18.2/POSIX.pm
        usr/lib/perl/5.18.2/Scalar
        usr/lib/perl/5.18.2/Scalar/Util.pm
        usr/lib/perl/5.18.2/Socket.pm
        usr/lib/perl/5.18.2/attributes.pm
        usr/lib/perl/5.18.2/auto
        usr/lib/perl/5.18.2/auto/Cwd
        usr/lib/perl/5.18.2/auto/Cwd/Cwd.bs
        usr/lib/perl/5.18.2/auto/Cwd/Cwd.so
        usr/lib/perl/5.18.2/auto/Fcntl
        usr/lib/perl/5.18.2/auto/Fcntl/Fcntl.bs
        usr/lib/perl/5.18.2/auto/Fcntl/Fcntl.so
        usr/lib/perl/5.18.2/auto/File
        usr/lib/perl/5.18.2/auto/File/Glob
        usr/lib/perl/5.18.2/auto/File/Glob/Glob.bs
        usr/lib/perl/5.18.2/auto/File/Glob/Glob.so
        usr/lib/perl/5.18.2/auto/Hash
        usr/lib/perl/5.18.2/auto/Hash/Util
        usr/lib/perl/5.18.2/auto/Hash/Util/Util.so
        usr/lib/perl/5.18.2/auto/IO
        usr/lib/perl/5.18.2/auto/IO/IO.bs
        usr/lib/perl/5.18.2/auto/IO/IO.so
        usr/lib/perl/5.18.2/auto/List
        usr/lib/perl/5.18.2/auto/List/Util
        usr/lib/perl/5.18.2/auto/List/Util/Util.bs
        usr/lib/perl/5.18.2/auto/List/Util/Util.so
        usr/lib/perl/5.18.2/auto/POSIX
        usr/lib/perl/5.18.2/auto/POSIX/POSIX.so
        usr/lib/perl/5.18.2/auto/Socket
        usr/lib/perl/5.18.2/auto/Socket/Socket.bs
        usr/lib/perl/5.18.2/auto/Socket/Socket.so
        usr/lib/perl/5.18.2/auto/attributes
        usr/lib/perl/5.18.2/auto/attributes/attributes.so
        usr/lib/perl/5.18.2/auto/re
        usr/lib/perl/5.18.2/auto/re/re.so
        usr/lib/perl/5.18.2/lib.pm
        usr/lib/perl/5.18.2/re.pm
        usr/lib/python2.7
        usr/lib/python2.7/dist-packages
        usr/lib/python2.7/dist-packages/debconf.py
        usr/lib/python3
        usr/lib/python3/dist-packages
        usr/lib/python3/dist-packages/debconf.py
        usr/lib/sasl2
        usr/lib/sasl2/libsasldb.so
        usr/lib/sasl2/libsasldb.so.2
        usr/lib/sasl2/libsasldb.so.2.0.25
        usr/lib/security
        usr/lib/security/pam_access.so
        usr/lib/security/pam_debug.so
        usr/lib/security/pam_deny.so
        usr/lib/security/pam_echo.so
        usr/lib/security/pam_env.so
        usr/lib/security/pam_exec.so
        usr/lib/security/pam_faildelay.so
        usr/lib/security/pam_filter.so
        usr/lib/security/pam_ftp.so
        usr/lib/security/pam_group.so
        usr/lib/security/pam_issue.so
        usr/lib/security/pam_keyinit.so
        usr/lib/security/pam_lastlog.so
        usr/lib/security/pam_limits.so
        usr/lib/security/pam_listfile.so
        usr/lib/security/pam_localuser.so
        usr/lib/security/pam_loginuid.so
        usr/lib/security/pam_mail.so
        usr/lib/security/pam_mkhomedir.so
        usr/lib/security/pam_motd.so
        usr/lib/security/pam_namespace.so
        usr/lib/security/pam_nologin.so
        usr/lib/security/pam_permit.so
        usr/lib/security/pam_pwhistory.so
        usr/lib/security/pam_rhosts.so
        usr/lib/security/pam_rootok.so
        usr/lib/security/pam_securetty.so
        usr/lib/security/pam_selinux.so
        usr/lib/security/pam_sepermit.so
        usr/lib/security/pam_shells.so
        usr/lib/security/pam_stress.so
        usr/lib/security/pam_succeed_if.so
        usr/lib/security/pam_tally.so
        usr/lib/security/pam_tally2.so
        usr/lib/security/pam_time.so
        usr/lib/security/pam_timestamp.so
        usr/lib/security/pam_tty_audit.so
        usr/lib/security/pam_umask.so
        usr/lib/security/pam_unix.so
        usr/lib/security/pam_userdb.so
        usr/lib/security/pam_warn.so
        usr/lib/security/pam_wheel.so
        usr/lib/security/pam_xauth.so
        usr/lib/tar
        usr/local
        usr/local/share
        usr/local/share/man
        usr/local/share/man/man1
        usr/local/share/man/man1/powershell.1.gz
        usr/sbin
        usr/sbin/add-shell
        usr/sbin/chgpasswd
        usr/sbin/chpasswd
        usr/sbin/cpgr
        usr/sbin/cppw
        usr/sbin/dpkg-preconfigure
        usr/sbin/dpkg-reconfigure
        usr/sbin/groupadd
        usr/sbin/groupdel
        usr/sbin/groupmod
        usr/sbin/grpck
        usr/sbin/grpconv
        usr/sbin/grpunconv
        usr/sbin/newusers
        usr/sbin/pam_timestamp_check
        usr/sbin/pwck
        usr/sbin/pwconv
        usr/sbin/pwunconv
        usr/sbin/remove-shell
        usr/sbin/rmt-tar
        usr/sbin/tarcat
        usr/sbin/useradd
        usr/sbin/userdel
        usr/sbin/usermod
        usr/sbin/vigr
        usr/sbin/vipw
        var
        var/cache
        var/cache/debconf
        var/lib
        var/lib/dpkg
        var/lib/dpkg/alternatives
        var/lib/dpkg/info
        var/lib/dpkg/parts
        var/lib/dpkg/updates
    `.split(/\r\n|\n|\r/).map(v => v.trim()).filter(v => v)
};

const v6_0_0_beta8_x86_64: Version = {
    nameAndVersion: 'v6.0.0_beta8_x86_64',
    appImageUrl: 'https://github.com/PowerShell/PowerShell/releases/download/v6.0.0-beta.8/PowerShell-6.0.0-beta.8-x86_64.AppImage',
    appImageSha256: 'F5AC46B8B27476474A0626BB20979B5598173BB67464CB1B5B04E3FBCB505F5C'.toLowerCase(),
    mustBeExtractedOneFileAtATime: false
}

export const allVersions = {
    '6.0.0-beta7': v6_0_0_beta7_x86_64,
    '6.0.0-beta8': v6_0_0_beta8_x86_64
};

export const latest = v6_0_0_beta8_x86_64;
export const {nameAndVersion, appImageUrl, appImageSha256} = latest;
