import { downloadUrlAsJson } from "./util";

export type Dictionary<T> = {[key: string]: T};

export async function githubApiRequest<T>(path: string): Promise<T> {
    return await downloadUrlAsJson<T>(`https://api.github.com/${ path }`, {
        headers: {
            'User-Agent': 'npm module get-powershell'
        }
    });
}

export async function getAllReleases(user: string = 'PowerShell', repo: string = 'PowerShell'): Promise<Array<MyRelease>> {
    const releases = await githubApiRequest<Array<Release>>(`repos/${ user }/${ repo }/releases`);
    return releases.map(r => parseShaSumsForRelease(r));
}

function parseShaSumsForRelease(r: Release): MyRelease {
    const sha256Sums: Dictionary<string> = {};
    r.body.replace(/-\s+([^ \r\n]+)\s*(?:\r\n|\n|\r)\s+-\s+([0-9A-F]{64})\s*(?:\r|\n)/g, (all, name, sha) => {
        sha256Sums[name] = sha; return '';
    });
    return {
        ...r,
        assets: r.assets.map(a => ({
            ...a,
            sha256: sha256Sums[a.name]
        }))
    };
}

interface Release {
    tag_name: string;
    name: string;
    prerelease: boolean;
    published_at: string;
    assets: Array<Asset>;
    body: string;
}
interface Asset {
    browser_download_url: string;
    name: string;
}
interface MyRelease extends Release {
    assets: Array<MyAsset>;
}
interface MyAsset extends Asset {
    sha256: string;
}

